<h1 align="center">
  <a href="https://github.com/orangebeard-io/python-client">
    <img src="https://raw.githubusercontent.com/orangebeard-io/python-client/master/.github/logo.svg" alt="Orangebeard.io Python Client" height="200">
  </a>
  <br>Orangebeard.io Python Client<br>
</h1>

<h4 align="center">Orangebeard Python client for Python based Orangebeard Listeners.</h4>



<div align="center">
  <h4>
    <a href="https://orangebeard.io">Orangebeard</a> |
    <a href="#installation">Installation</a>
  </h4>
</div>

## Installation

### Install the pip package

`pip install orangebeard-client`
